/*
 * panel-applet-private.h:
 *
 * Authors:
 *   Mark McLoughlin <mark@skynet.ie>
 *
 * Copyright 2001 Sun Microsystems, Inc.
 */

#ifndef __PANEL_APPLET_PRIVATE_H__
#define __PANEL_APPLET_PRIVATE_H__

#include "panel-applet.h"

G_BEGIN_DECLS

void panel_applet_save_yourself (PanelApplet *applet,
				 const gchar *global_key,
				 const gchar *private_key);

G_END_DECLS

#endif /* __PANEL_APPLET_PRIVATE_H__ */
